@@ -16,14 +16,30 @@ import pandas as pd
 import pyqtgraph as pg
 from pyqtgraph.Qt import QtWidgets, QtCore
 from pyqtgraph.parametertree import Parameter, ParameterTree
-from ruamel.yaml import YAML, YAMLError
 from tqdm import tqdm
 import cv2 as cv
 
 from .params.prjparam import PrjParam
 from .typeoverloads import FilePath
 
-yaml = YAML()
+# -----
+# For Pyyaml
+# import yaml
+# from yaml import YAMLError
+# def yamlLoad(stream, loader=yaml.UnsafeLoader):
+#   return yaml.load(stream, loader)
+# def yamlDump(data, stream, dumper=yaml.Dumper):
+#   return yaml.dump(data, stream, dumper, sort_keys=False)
+
+# -----
+# For ruamel yaml
+# -----
+from ruamel.yaml import YAML, YAMLError
+yaml = YAML(typ='unsafe')
+def yamlLoad(stream):
+  return yaml.load(stream)
+def yamlDump(data, stream):
+  return yaml.dump(data, stream)
 
 
 def mproc_apply(func, iterLst, descr='', iterArgPos=0, extraArgs=(), showProgress=True, applyAsync=True, total=None, pool=None):
@@ -237,12 +253,12 @@ def saveToFile(saveObj, savePath: FilePath, allowOverwriteDefault=False):
     # Known pycharm bug
     # noinspection PyTypeChecker
     with open(savePath, 'w') as saveFile:
-      yaml.dump(saveObj, saveFile)
+      yamlDump(saveObj, saveFile)
 
 
 def attemptFileLoad(fpath: FilePath , openMode='r') -> t.Union[dict, bytes]:
   with open(fpath, openMode) as ifile:
-    loadObj = yaml.load(ifile)
+    loadObj = yamlLoad(ifile)
   return loadObj
 
 
@@ -468,7 +484,7 @@ def docParser(docstring: str):
   for param in parsed.params:
     stream = StringIO(param.description)
     try:
-      paramDoc = yaml.load(stream)
+      paramDoc = yamlLoad(stream)
     except YAMLError:
       # Some problem parsing, treat as string
       paramDoc = param.description
@@ -486,7 +502,7 @@ def docParser(docstring: str):
 
 def paramWindow(param: Parameter):
   tree = flexibleParamTree(param)
-  tree.setHeaderHidden(True)
+  setParamsExpanded(tree, True)
   dlg = QtWidgets.QDialog()
   layout = QtWidgets.QVBoxLayout()
   dlg.setLayout(layout)
@@ -568,9 +584,15 @@ def popupFilePicker(parent=None, winTitle: str='', fileFilter: str='', existing=
 
   if fileDlg.exec_():
     # Append filter type
-    suffMatch = re.search(r'\*\.?(\w+)', fileDlg.selectedNameFilter())
+    singleExtReg = r'(\.\w+)'
+    # Extensions of type 'myfile.ext.is.multi.part' need to capture repeating pattern of singleExt
+    suffMatch = re.search(rf'({singleExtReg}+)', fileDlg.selectedNameFilter())
     if suffMatch:
-      fileDlg.setDefaultSuffix(suffMatch.group(1))
+      # Strip leading '.' if it exists
+      ext = suffMatch.group(1)
+      if ext.startswith('.'):
+        ext = ext[1:]
+      fileDlg.setDefaultSuffix(ext)
     fList = fileDlg.selectedFiles()
   else:
     fList = []
