@@ -642,7 +642,7 @@ class ParamEditor(QtWidgets.QDockWidget):
     self.expandAllBtn.clicked.connect(lambda: fns.setParamsExpanded(self.tree))
     self.collapseAllBtn.clicked.connect(lambda: fns.setParamsExpanded(self.tree, False))
     self.saveAsBtn.clicked.connect(self.saveParamValues_gui)
-    self.applyBtn.clicked.connect(self.applyChanges)
+    self.applyBtn.clicked.connect(lambda: self.applyChanges())
 
   def _mkMetaTree(self):
     self._metaParamGrp = Parameter.create(name='Meta Parameters', type='group')
